###################################################
### chunk number 1: preliminaries
###################################################
library("bvpSolve")
options(prompt = "> ")
options(width=70)


###################################################
### chunk number 2: 
###################################################
fun<- function(x,y,pars)
{
 list(c(y[2],
   1/ks*(-x*y[2]+y[1]-(1+ks*pi*pi)*cos(pi*x)-pi*x*sin(pi*x)))
     )
}


###################################################
### chunk number 3: 
###################################################
ks <- 0.1
x  <- seq(-1,1,by=0.01)
print(system.time(
sol1  <- bvpshoot(yini=c(-1,NA),yend=c(1,NA),x=x,func=fun,guess=0)
))

print(system.time(
sol2  <- bvptwp(yini=c(-1,NA),yend=c(1,NA),x=x,func=fun, guess=0)
))


###################################################
### chunk number 4: pr7a
###################################################
plot(sol2[,1],sol2[,3],type="l",main="test problem 7, ksi=0.1",
     lwd=2,col="red")
points(sol1[,1],sol1[,3],col="green",pch="x")
legend("topright",c("bvptwp", "bvpshoot"),
        lty=c(1,NA,NA), pch=c(NA,1,3),col=c("red", "green") )


###################################################
### chunk number 5: pr7a
###################################################
plot(sol2[,1],sol2[,3],type="l",main="test problem 7, ksi=0.1",
     lwd=2,col="red")
points(sol1[,1],sol1[,3],col="green",pch="x")
legend("topright",c("bvptwp", "bvpshoot"),
        lty=c(1,NA,NA), pch=c(NA,1,3),col=c("red", "green") )


###################################################
### chunk number 6: 
###################################################
ks <-0.0001

print(system.time(
sol2  <- bvptwp(yini=c(-1,NA),yend=c(1,NA),x=seq(-1,1,by=0.01),
           func=fun, guess=0)
))


###################################################
### chunk number 7: pr7b
###################################################
plot(sol2[,1],sol2[,3],type="l",main="test problem 7, ksi=0.0001",
     lwd=2,col="red")



###################################################
### chunk number 8: pr7b
###################################################
plot(sol2[,1],sol2[,3],type="l",main="test problem 7, ksi=0.0001",
     lwd=2,col="red")



###################################################
### chunk number 9: 
###################################################
fsub <- function (t,Y,pars)
{ return(list(c(f1 = Y[2],
                f2 = (Y[1]*Y[4] - Y[3]*Y[2])/eps,
	              f3 = Y[4],
              	f4 = Y[5],
              	f5 = Y[6],
	              f6 = (-Y[3]*Y[6] - Y[1]*Y[2])/eps)))
}
eps <- 0.001
x <- seq(0,1,len=100)


###################################################
### chunk number 10: 
###################################################
print(system.time(
Soltwp <- bvptwp(x=x,func=fsub,guess= c(2,0,0),
                  yini=c(-1,NA,0,0,NA,NA), yend=c(1,NA,0,0,NA,NA))
))


###################################################
### chunk number 11: 
###################################################
eps <- 1e-9
Soltwp2 <- NA
Soltwp2 <- try(bvptwp(x=x,func=fsub,guess= c(2,0,0),
                  yini=c(-1,NA,0,0,NA,NA), yend=c(1,NA,0,0,NA,NA)),
    silent = TRUE)

cat(Soltwp2)



###################################################
### chunk number 12: swirl
###################################################
pairs(Soltwp, main="swirling flow III, eps=0.01", col="blue")


###################################################
### chunk number 13: swirl
###################################################
pairs(Soltwp, main="swirling flow III, eps=0.01", col="blue")


###################################################
### chunk number 14: 
###################################################
eps <- 0.001
xguess <- x
yguess <- matrix(nr=6, nc=length(xguess), data=0.)
slope  <- 0.375-0.9129
yguess[1,] <- 2*xguess -1
yguess[2,] <- 2
print(system.time(Sol2 <- bvptwp(x=x,func=fsub,guess= c(2,0,0),
  xguess=xguess,yguess=yguess,yini=c(-1,NA,0,0,NA,NA),
  yend=c(1,NA,0,0,NA,NA))))


###################################################
### chunk number 15: 
###################################################
musn <- function(x,Y,pars)
{
  with (as.list(Y),
  {
   du=0.5*u*(w-u)/v
   dv=-0.5*(w-u)
   dw=(0.9-1000*(w-y)-0.5*w*(w-u))/z
   dz=0.5*(w-u)
   dy=-100*(y-w)
   return(list(c(du,dv,dw,dz,dy)))
  })
}


###################################################
### chunk number 16: 
###################################################
init <- c(u=1,v=1,w=1,z=-10,y=NA)


###################################################
### chunk number 17: 
###################################################
yend  <- function (Y,yini,pars)  with (as.list(Y), w-y)


###################################################
### chunk number 18: 
###################################################
print(system.time(
sol   <-bvpshoot(yini= init, x=seq(0,1,by=0.05),func=musn,
           yend=yend,guess=1,atol=1e-10,rtol=0)
))


###################################################
### chunk number 19: musn
###################################################
pairs(sol,main="musn")


###################################################
### chunk number 20: musn
###################################################
pairs(sol,main="musn")


###################################################
### chunk number 21: 
###################################################
mathieu <- function(x,y,lambda)
    list(c(y[2],
        -(lambda-10*cos(2*x))*y[1]))


###################################################
### chunk number 22: 
###################################################
init <- c(1,0)
sol  <- bvpshoot(yini=init,yend=c(NA,0),x=seq(0,pi,by=0.01),
        func=mathieu, guess=NULL, extra=15)


###################################################
### chunk number 23: mat
###################################################
plot(sol)


###################################################
### chunk number 24: mat
###################################################
plot(sol)


###################################################
### chunk number 25: 
###################################################
attr(sol,"roots")  # root gives the value of "lam" (17.10684)


